@@ -1,3 +1,4 @@
+from marshy.marshaller.datetime_marshaller import DatetimeMarshaller
 from marshy.marshaller.no_op_marshaller import NoOpMarshaller
 from marshy.marshaller.bool_marshaller import BoolMarshaller
 from marshy.marshaller.primitive_marshaller import PrimitiveMarshaller
@@ -7,5 +8,6 @@ bool_marshaller = BoolMarshaller()
 float_marshaller = PrimitiveMarshaller(float)
 int_marshaller = PrimitiveMarshaller(int)
 str_marshaller = PrimitiveMarshaller(str)
+datetime_marshaller = DatetimeMarshaller()
 
 none_marshaller = NoOpMarshaller(type(None))
